changeset 28932:f8b0ac62f238

Use the term `invalid' instead of `illegal'.
author Gerd Moellmann <gerd@gnu.org>
date Tue, 16 May 2000 14:29:08 +0000
parents bb9ed79dd3fd
children bb0cf4868e70
files src/emacs.c src/msdos.c src/print.c src/w32.c src/xdisp.c
diffstat 5 files changed, 8 insertions(+), 8 deletions(-) [+]
line wrap: on
line diff
--- a/src/emacs.c	Tue May 16 11:47:30 2000 +0000
+++ b/src/emacs.c	Tue May 16 14:29:08 2000 +0000
@@ -314,7 +314,7 @@
 }
 #endif /* SIGUSR2 */
 
-/* Handle bus errors, illegal instruction, etc. */
+/* Handle bus errors, invalid instruction, etc. */
 SIGTYPE
 fatal_error_signal (sig)
      int sig;
--- a/src/msdos.c	Tue May 16 11:47:30 2000 +0000
+++ b/src/msdos.c	Tue May 16 14:29:08 2000 +0000
@@ -372,7 +372,7 @@
 {
   __dpmi_regs regs;
 
-  if (offset < 0 || count < 0)	/* paranoia; illegal values crash DOS/V */
+  if (offset < 0 || count < 0)	/* paranoia; invalid values crash DOS/V */
     return;
 
   regs.h.ah = 0xff;	/* update relocated screen */
--- a/src/w32.c	Tue May 16 11:47:30 2000 +0000
+++ b/src/w32.c	Tue May 16 14:29:08 2000 +0000
@@ -468,7 +468,7 @@
   HANDLE dir_handle;
   int len = 0;
 
-  /* must be valid filename, no wild cards or other illegal characters */
+  /* must be valid filename, no wild cards or other invalid characters */
   if (strpbrk (name, "*?|<>\""))
     return 0;
 
@@ -1913,7 +1913,7 @@
     }
 
   name = (char *) map_w32_filename (path, &path);
-  /* must be valid filename, no wild cards or other illegal characters */
+  /* must be valid filename, no wild cards or other invalid characters */
   if (strpbrk (name, "*?|<>\""))
     {
       errno = ENOENT;
--- a/src/xdisp.c	Tue May 16 11:47:30 2000 +0000
+++ b/src/xdisp.c	Tue May 16 14:29:08 2000 +0000
@@ -878,7 +878,7 @@
 /* Return the next character from STR which is MAXLEN bytes long.
    Return in *LEN the length of the character.  This is like
    STRING_CHAR_AND_LENGTH but never returns an invalid character.  If
-   we find one, we return a `?', but with the length of the illegal
+   we find one, we return a `?', but with the length of the invalid
    character.  */
 
 static INLINE int
@@ -891,7 +891,7 @@
   c = STRING_CHAR_AND_LENGTH (str, maxlen, *len);
   if (!CHAR_VALID_P (c, 1))
     /* We may not change the length here because other places in Emacs
-       don't use this function, i.e. they silently accept illegal
+       don't use this function, i.e. they silently accept invalid
        characters.  */
     c = '?';
--- a/src/print.c	Tue May 16 11:47:30 2000 +0000
+++ b/src/print.c	Tue May 16 14:29:08 2000 +0000
@@ -1490,7 +1490,7 @@
 	    int print_length, i;
 	    Lisp_Object halftail = obj;
 
 	    /* Negative values of print-length are illegal in CL.
 	       Treat them like nil, as CMUCL does.  */
 	    if (NATNUMP (Vprint_length))
 	      print_length = XFASTINT (Vprint_length);
@@ -1594,7 +1594,7 @@
 	  PRINTCHAR ('\"');
 
 	  /* Don't print more characters than the specified maximum.
-	     Negative values of print-length are illegal.  Treat them
+	     Negative values of print-length are invalid.  Treat them
 	     like a print-length of nil.  */
 	  if (NATNUMP (Vprint_length)
 	      && XFASTINT (Vprint_length) < size_in_chars)
@@ -1490,7 +1490,7 @@
 	    Lisp_Object halftail = obj;
 
-	    /* Negative values of print-length are illegal in CL.
+	    /* Negative values of print-length are invalid in CL.
 	       Treat them like nil, as CMUCL does.  */
 	    if (NATNUMP (Vprint_length))